<?php

namespace Hp;

//  PROJECT HONEY POT ADDRESS DISTRIBUTION SCRIPT
//  For more information visit: http://www.projecthoneypot.org/
//  Copyright (C) 2004-2022, Unspam Technologies, Inc.
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
//  02111-1307  USA
//
//  If you choose to modify or redistribute the software, you must
//  completely disconnect it from the Project Honey Pot Service, as
//  specified under the Terms of Service Use. These terms are available
//  here:
//
//  http://www.projecthoneypot.org/terms_of_service_use.php
//
//  The required modification to disconnect the software from the
//  Project Honey Pot Service is explained in the comments below. To find the
//  instructions, search for:  *** DISCONNECT INSTRUCTIONS ***
//
//  Generated On: Mon, 22 Aug 2022 09:52:14 -0400
//  For Domain: speedos.ddnsfree.com
//
//

//  *** DISCONNECT INSTRUCTIONS ***
//
//  You are free to modify or redistribute this software. However, if
//  you do so you must disconnect it from the Project Honey Pot Service.
//  To do this, you must delete the lines of code below located between the
//  *** START CUT HERE *** and *** FINISH CUT HERE *** comments. Under the
//  Terms of Service Use that you agreed to before downloading this software,
//  you may not recreate the deleted lines or modify this software to access
//  or otherwise connect to any Project Honey Pot server.
//
//  *** START CUT HERE ***

define('__REQUEST_HOST', 'hpr8.projecthoneypot.org');
define('__REQUEST_PORT', '80');
define('__REQUEST_SCRIPT', '/cgi/serve.php');

//  *** FINISH CUT HERE ***

interface Response
{
    public function getBody();
    public function getLines(): array;
}

class TextResponse implements Response
{
    private $content;

    public function __construct(string $content)
    {
        $this->content = $content;
    }

    public function getBody()
    {
        return $this->content;
    }

    public function getLines(): array
    {
        return explode("\n", $this->content);
    }
}

interface HttpClient
{
    public function request(string $method, string $url, array $headers = [], array $data = []): Response;
}

class ScriptClient implements HttpClient
{
    private $proxy;
    private $credentials;

    public function __construct(string $settings)
    {
        $this->readSettings($settings);
    }

    private function getAuthorityComponent(string $authority = null, string $tag = null)
    {
        if(is_null($authority)){
            return null;
        }
        if(!is_null($tag)){
            $authority .= ":$tag";
        }
        return $authority;
    }

    private function readSettings(string $file)
    {
        if(!is_file($file) || !is_readable($file)){
            return;
        }

        $stmts = file($file);

        $settings = array_reduce($stmts, function($c, $stmt){
            list($key, $val) = \array_pad(array_map('trim', explode(':', $stmt)), 2, null);
            $c[$key] = $val;
            return $c;
        }, []);

        $this->proxy       = $this->getAuthorityComponent($settings['proxy_host'], $settings['proxy_port']);
        $this->credentials = $this->getAuthorityComponent($settings['proxy_user'], $settings['proxy_pass']);
    }

    public function request(string $method, string $uri, array $headers = [], array $data = []): Response
    {
        $options = [
            'http' => [
                'method' => strtoupper($method),
                'header' => $headers + [$this->credentials ? 'Proxy-Authorization: Basic ' . base64_encode($this->credentials) : null],
                'proxy' => $this->proxy,
                'content' => http_build_query($data),
            ],
        ];

        $context = stream_context_create($options);
        $body = file_get_contents($uri, false, $context);

        if($body === false){
            trigger_error(
                "Unable to contact the Server. Are outbound connections disabled? " .
                "(If a proxy is required for outbound traffic, you may configure " .
                "the honey pot to use a proxy. For instructions, visit " .
                "http://www.projecthoneypot.org/settings_help.php)",
                E_USER_ERROR
            );
        }

        return new TextResponse($body);
    }
}

trait AliasingTrait
{
    private $aliases = [];

    public function searchAliases($search, array $aliases, array $collector = [], $parent = null): array
    {
        foreach($aliases as $alias => $value){
            if(is_array($value)){
                return $this->searchAliases($search, $value, $collector, $alias);
            }
            if($search === $value){
                $collector[] = $parent ?? $alias;
            }
        }

        return $collector;
    }

    public function getAliases($search): array
    {
        $aliases = $this->searchAliases($search, $this->aliases);
    
        return !empty($aliases) ? $aliases : [$search];
    }

    public function aliasMatch($alias, $key)
    {
        return $key === $alias;
    }

    public function setAlias($key, $alias)
    {
        $this->aliases[$alias] = $key;
    }

    public function setAliases(array $array)
    {
        array_walk($array, function($v, $k){
            $this->aliases[$k] = $v;
        });
    }
}

abstract class Data
{
    protected $key;
    protected $value;

    public function __construct($key, $value)
    {
        $this->key = $key;
        $this->value = $value;
    }

    public function key()
    {
        return $this->key;
    }

    public function value()
    {
        return $this->value;
    }
}

class DataCollection
{
    use AliasingTrait;

    private $data;

    public function __construct(Data ...$data)
    {
        $this->data = $data;
    }

    public function set(Data ...$data)
    {
        array_map(function(Data $data){
            $index = $this->getIndexByKey($data->key());
            if(is_null($index)){
                $this->data[] = $data;
            } else {
                $this->data[$index] = $data;
            }
        }, $data);
    }

    public function getByKey($key)
    {
        $key = $this->getIndexByKey($key);
        return !is_null($key) ? $this->data[$key] : null;
    }

    public function getValueByKey($key)
    {
        $data = $this->getByKey($key);
        return !is_null($data) ? $data->value() : null;
    }

    private function getIndexByKey($key)
    {
        $result = [];
        array_walk($this->data, function(Data $data, $index) use ($key, &$result){
            if($data->key() == $key){
                $result[] = $index;
            }
        });

        return !empty($result) ? reset($result) : null;
    }
}

interface Transcriber
{
    public function transcribe(array $data): DataCollection;
    public function canTranscribe($value): bool;
}

class StringData extends Data
{
    public function __construct($key, string $value)
    {
        parent::__construct($key, $value);
    }
}

class CompressedData extends Data
{
    public function __construct($key, string $value)
    {
        parent::__construct($key, $value);
    }

    public function value()
    {
        $url_decoded = base64_decode(str_replace(['-','_'],['+','/'],$this->value));
        if(substr(bin2hex($url_decoded), 0, 6) === '1f8b08'){
            return gzdecode($url_decoded);
        } else {
            return $this->value;
        }
    }
}

class FlagData extends Data
{
    private $data;

    public function setData($data)
    {
        $this->data = $data;
    }

    public function value()
    {
        return $this->value ? ($this->data ?? null) : null;
    }
}

class CallbackData extends Data
{
    private $arguments = [];

    public function __construct($key, callable $value)
    {
        parent::__construct($key, $value);
    }

    public function setArgument($pos, $param)
    {
        $this->arguments[$pos] = $param;
    }

    public function value()
    {
        ksort($this->arguments);
        return \call_user_func_array($this->value, $this->arguments);
    }
}

class DataFactory
{
    private $data;
    private $callbacks;

    private function setData(array $data, string $class, DataCollection $dc = null)
    {
        $dc = $dc ?? new DataCollection;
        array_walk($data, function($value, $key) use($dc, $class){
            $dc->set(new $class($key, $value));
        });
        return $dc;
    }

    public function setStaticData(array $data)
    {
        $this->data = $this->setData($data, StringData::class, $this->data);
    }

    public function setCompressedData(array $data)
    {
        $this->data = $this->setData($data, CompressedData::class, $this->data);
    }

    public function setCallbackData(array $data)
    {
        $this->callbacks = $this->setData($data, CallbackData::class, $this->callbacks);
    }

    public function fromSourceKey($sourceKey, $key, $value)
    {
        $keys = $this->data->getAliases($key);
        $key = reset($keys);
        $data = $this->data->getValueByKey($key);

        switch($sourceKey){
            case 'directives':
                $flag = new FlagData($key, $value);
                if(!is_null($data)){
                    $flag->setData($data);
                }
                return $flag;
            case 'email':
            case 'emailmethod':
                $callback = $this->callbacks->getByKey($key);
                if(!is_null($callback)){
                    $pos = array_search($sourceKey, ['email', 'emailmethod']);
                    $callback->setArgument($pos, $value);
                    $this->callbacks->set($callback);
                    return $callback;
                }
            default:
                return new StringData($key, $value);
        }
    }
}

class DataTranscriber implements Transcriber
{
    private $template;
    private $data;
    private $factory;

    private $transcribingMode = false;

    public function __construct(DataCollection $data, DataFactory $factory)
    {
        $this->data = $data;
        $this->factory = $factory;
    }

    public function canTranscribe($value): bool
    {
        if($value == '<BEGIN>'){
            $this->transcribingMode = true;
            return false;
        }

        if($value == '<END>'){
            $this->transcribingMode = false;
        }

        return $this->transcribingMode;
    }

    public function transcribe(array $body): DataCollection
    {
        $data = $this->collectData($this->data, $body);

        return $data;
    }

    public function collectData(DataCollection $collector, array $array, $parents = []): DataCollection
    {
        foreach($array as $key => $value){
            if($this->canTranscribe($value)){
                $value = $this->parse($key, $value, $parents);
                $parents[] = $key;
                if(is_array($value)){
                    $this->collectData($collector, $value, $parents);
                } else {
                    $data = $this->factory->fromSourceKey($parents[1], $key, $value);
                    if(!is_null($data->value())){
                        $collector->set($data);
                    }
                }
                array_pop($parents);
            }
        }
        return $collector;
    }

    public function parse($key, $value, $parents = [])
    {
        if(is_string($value)){
            if(key($parents) !== NULL){
                $keys = $this->data->getAliases($key);
                if(count($keys) > 1 || $keys[0] !== $key){
                    return \array_fill_keys($keys, $value);
                }
            }

            end($parents);
            if(key($parents) === NULL && false !== strpos($value, '=')){
                list($key, $value) = explode('=', $value, 2);
                return [$key => urldecode($value)];
            }

            if($key === 'directives'){
                return explode(',', $value);
            }

        }

        return $value;
    }
}

interface Template
{
    public function render(DataCollection $data): string;
}

class ArrayTemplate implements Template
{
    public $template;

    public function __construct(array $template = [])
    {
        $this->template = $template;
    }

    public function render(DataCollection $data): string
    {
        $output = array_reduce($this->template, function($output, $key) use($data){
            $output[] = $data->getValueByKey($key) ?? null;
            return $output;
        }, []);
        ksort($output);
        return implode("\n", array_filter($output));
    }
}

class Script
{
    private $client;
    private $transcriber;
    private $template;
    private $templateData;
    private $factory;

    public function __construct(HttpClient $client, Transcriber $transcriber, Template $template, DataCollection $templateData, DataFactory $factory)
    {
        $this->client = $client;
        $this->transcriber = $transcriber;
        $this->template = $template;
        $this->templateData = $templateData;
        $this->factory = $factory;
    }

    public static function run(string $host, int $port, string $script, string $settings = '')
    {
        $client = new ScriptClient($settings);

        $templateData = new DataCollection;
        $templateData->setAliases([
            'doctype'   => 0,
            'head1'     => 1,
            'robots'    => 8,
            'nocollect' => 9,
            'head2'     => 1,
            'top'       => 2,
            'legal'     => 3,
            'style'     => 5,
            'vanity'    => 6,
            'bottom'    => 7,
            'emailCallback' => ['email','emailmethod'],
        ]);

        $factory = new DataFactory;
        $factory->setStaticData([
            'doctype' => '<!DOCTYPE html>',
            'head1'   => '<html><head>',
            'head2'   => '<title></title></head>',
            'top'     => '<body><div align="center">',
            'bottom'  => '</div></body></html>',
        ]);
        $factory->setCompressedData([
            'robots'    => 'H4sIAAAAAAAAA7PJTS1JVMhLzE21VSrKT8ovKVZSSM7PK0nNK7FVSsvPyckv18nLz8xLSa0A0olFyRmZZalKdgCebds4NwAAAA',
            'nocollect' => 'H4sIAAAAAAAAA7PJTS1JVMhLzE21VcrL103NTczM0U3Oz8lJTS7JzM9TUkjOzytJzSuxVdJXsgMAKsBXli0AAAA',
            'legal'     => 'H4sIAAAAAAAAA7Vc23LcOJJ9369gyBMeT4TblnyR7JXaEWpb3dZEj-yRZDvmkUWiqtBmkRyQlLr26xfIAzITIIuelbQPLNNVJAjk5eTJTFAnbbooVJKpoqjTPNfl6ue9_b1kUZlcGTp1PzV1mvmf3v3XSWvcR5407bZQP-8tq7L9aZludLH97ySrOqOVeZpsqrJyt6njvXePy0VTHycnC-NP3dn1-sT-Xvaj5Lqpi9SOUFal2nunytakumhOnruL3rkb2sp9Vi0N8-jN0fHjRwf7BzSWUe4zXdFla1xwcLDvrjjAFd_oCp5BNJmr2n1e0BMaOq8NDdn1t51t3Oe5G_GQbkkL97l-_OjtEf2_oYndpHyO-ex85lnKFz3ZC6f--pgenJa05CWfX6n-ksPjdTj8yeLdidOF1UFRmZ9v17pV77KT5-67dyfPF-_Cx_-LFrvBJBbu86vuB_x67j4_n9ITraxf0x0nz9v87pp3hxIi2JL4aDmLhiaR0yW0TEXSLn_iXyMxeilY_Wd8pfvi9TENU63YZGhwPWdtuk2W9ki7XFc3uunSIrnVRWFNvlSNtEHMgORU0UQbmk1FxlJ0fG6m7M0d2dpPx37-vWOh4PtcCIi0vqUvzA1fODFml_jVv7DGPjKBpjcBdyXJshkUfUWKvrx2n79cPYySb9kvK1qg6adnlUOOMZ7j2s-Rfm7hAe70Gd3akkh1u2P5mmz4I4QJ6ads26SZfgZ2WDpVz0gLdJ7OWcZSGaPa3gRWrAYNhGFjnTJQ-m_NeETSz3X_xSsBYbiWMKUm21FkxymZt87YS6dsisw8rXllbPjXn8jZ6dqzfz6MhhesIPxC62oVSwd-jR9pKtdrxjBMcWIdxdgwVsJ4oc_mKZ3zFNrBmoEgRjz7X-4UmKzoPmDpKmGomZhHCuXQ4N5y3r6F169gxnTVLT2NBlRzNlSbKus2CxvSkjo1VbndVF2TdEWrjK5MslbWwnRm4wmMzPhFzYy46rZJrcxGN42u3EWpaS1YWdDK1U9qa02HIQvSrm7Ctf5HwcIdZcMmiVsJLMwAypcEG5_mptu0ldna80SXfs2FKlfteuuneelG-HL2MMYJmOjIVwx55rbq8ectLlsmbKnNsr_xB8KpJ4QDUyuTaVDrxbngkd0kABrZQBwIEwz7MUATwQR3pcEAnn8IDtDOg_4PFqYmFtb6YLLoSQnYTsOP94GPPQVXICoK59sZtOB9qYnhIg2vP-VTMrSL64cxE8zrD8Vr6ealmKVCGoTHiDU7lgcKCEoFzqrIZQpnAm8GxePLFQcTIQRMscxZQrphFJ14Zn_vnCtu0qJIbvSNFUqSrdPafm_BR0nAEBzklNcJTW1iTeF0wYY7yXoZSncLueF7iJWsBvH-RgBxdsEX_PIwRrCE27WDDmDyKeE9O7hnaEgyhiD8A7eqpvBC917kY4g9fQX30SS27RAaGyj8f-DqdjrfyRgIIZ73gGYjoNDHN0KSXf4GccIUM59EOfKR8wpxb8kgZao5WzIq78o8LdsRQc5YdjhmKJ-TD2clZCjD8g6OCcBzaGEY74xCxQdw1wcKG-Jx-AXpnGLNO7G8QF4GBSIBaPov3hyLBQvTuJIWkDGC-mVyRlEG9wOUwAKh9p6LOMTd4Uu5Fyrww9oNkEb9uQsxyASUQBj2AoEARIheYCgB8MzBOrLeqs_d5sjQWhdVU9VD8J_FMjc_-Ie67W2zj390QQSFFBwufnOfp48fHR49UN7KywUsVPOhwtCsarKggsKi5_w0jOHTW6lwayqf7ZztE4S9zNJAo7N1UlTlyn3p-F9mdKObJEvLqt4mmV6lllq2PbiTEYG4IagwVrD2hPHf0tQLxQvIcwYe-qLm-D-hQ5iwmeFSbipU-sjJ8-qiH_8Q47dkyOuWEXGetMPcvSkvGfDc8VFQCZw-Onrh7_-_W8gkprU7MW2N5RB70LGggfo3dAniAOe63jLen0urENkkMmQ4OARXyVvFU9Y9KPToDugCUQFY-xSO_XpCznINf0v4XCs_zozB3qq0UUWTGOXy6rRINjYpsv_ochmGkTZOjGnuJcoDu9JHzMMMYB0Ex0Gg13T9BZHTT78-ED64AC2win5YjTJh690Qa-4kDHCytj3n4ZatbZNcr3SbtiqxfK3WriSVLO0_Ql7rQOnWXk5_D-yFE3HUOD11HRmwlvFDWJtdGAx4KOW8HAnXkxsyqr_CtEKuGzvsjlpQT5yIRDSwNhROZjJWB1RbfgjduxpSrH6WM5LOuoXOopA0MelVEskTxa1ZnpTmae3L7I58p6TMqn_W7JoItwaz6a3oyMe1nZzqgXIkUahdosSUDWqFc5Zbb_5HKF35TIqjdDiUNczfxzgG1kkVXBR3siwyv75s5wvkjAjAtAVKf42UUT_D7S4-LEZB5EMCi1qj5GYi7Mfkr0rGaxy-QtkBxQEYcMdFk68YyUZ7ymo_3o_FTgaj5UQCwit4A4VlsRfjlFKtJ8hNTXSFQJnz93JwlFM_zqafXe2LXmmZN9VGJUu7qnadFakFtaYzK2W2ycouQlddX3XtQl14jG3kXJq-pmq1LggOhI8CIQLlZsCEekgvBxmejm2T7BvEHEXkVEiJjAeh2oSFGV_oViEAeqldjlheZ2LrFp2B0FKu0JS5t71cj-MDfOG2d3FPAWYDetMaF42atVK11xarqBIcIeUKx1pF8qDFXcj5gAqh3lstGBj6ox1i_IHsqtH1X6742edgJqhMrcUjP3-Wj9tNUMmWkC0vOD-CRuEYIHaNmAU9R2XRIt9_GgvcIvnL3mQspLDMS64QRK2-63N8eXRwfMYD3RXve-FfBinqbCzLWn2jklXXp2_oT8SMduOz4levjz-6s9s1r0UgTmwJ1qzFRODU8OFKuN1E2Q3UdhPj1V_4tBJ2I5x3SJH9DH4__0EhuyqShSoGriqdGPxdRA7RLkLxotzNuEhKGIGW0ZpINpcfgrK8kAf1ff5NiKG5V_ro6M0xJcJPyCHOLu9jI5ZxBGUMX7acJy9V7JodrWwieZb54ATLk7n1n_VY-046MXT7PAgFWKCHClit3zOgWTuv93tf9GkhMIskPWS-Qw_Tu_UoZhwePxVmS22X92i1I8Va8-eomywGfvzozcvjcR7pa7GwrGIavL7HJP4pzQVA_A8MfDdbmI6Ugg-ig4HVIQSjWO2_r1jwYqlngWmZv7LvCzKfBwGgx09fpi12lMO4rTzj1Lk2rU2xmrRprXQ5A3gmKKcWM0dJblDT4eHxRK6Vsj9DZXBYfKp5EweaeuIYxxGbskoYEPXp7Xz3NB-m_duQUKA5jBl_ujs-XATQlIu2hewlZHz6NYYwbjc1TbTg68C1EWi9IUX53WAO_eF5PRoopBFsegF6lXw7BV6UU6Rdjt2PHtEKGweIZDy10zxYleeEmYgK8QJ3m-3XoCXnIenVftgE3H8LY2O3uv7IDyNm8Otdi1yDv78foxz8gmSBzVWQthZ7A4gJip7mdNEzTCIK8hlUKVGArDbyBtE8QdMUcsEWmAnHkvG18BfN8ZuiUKu01XYxQIJYW78H0CejfcXGjzmBMW5oQSC9JYlIhUXTXgwBCn4WfdEW5jU77aZWWRtPGTEfueWdMwaHOQE5B8fAyhdiRwtsoRBZeOe9tFeY9OqgnpnF5T4BnLWWt_pWUOPl6B142bGjZ3FbRTz123zJtr9ygqZJJEXJZ0Gp4ROAAZoTo8YpKe4mnsW5DcGvgvxPsts9Vjy-GDYoULpwwT-g__X17nr9cL4jcGHThx52Y3n9YWvbU4Hv7bjSM7KXvlg9x6t1ceMS_01adkubYtjplqukVOZGFjlL-AERgSLstZFDoZePjh2hkwF1Y3cThY8miSZ9Ot_qbE3VNY1Kbivz3U2u3dZuz05SpmVpJ67atF5XPX0I1l-J9rksx4umJnEyTHYTyTyL2dKnEdU94Mh3jr7OTDd6EWzacMdvQw_6A2GExeM7W9R13KbYf4l07ZnYdid3TqZi1x63dvxSd3FgulNukBFsOiiEA41lco5WJ8ONR5JRw7ond28mni-yLj10f1_JvHaP4QD1Ip8gk7LKHZMdgu2XwHoKFo2sSkbbZMTemDOrz8O7MvyR98JAr7m5sTvn-4WF3Yo8YHdMjnNYIfpfg3LJsCNgfx9ihjeZwIdruU0FlGjeD0TeghJhFndR_h6owlRClUOZGeUD0D58-v2NO2PIFQ9AcWM5z1rEfML6yMB6EQQFaIjCfcnUmhRJNP_812HQO5nI1dgpNrFPofD-ROi4jcDHI-Co0LHL40iniD7Yl7EKEvqqZnBAyQ9pst-p1nugRaQYZy5DMoKxd2-uoKG5KwAOjoqlyFqpwdiKEnE9UbeaKDrv74tdgihGoEIg8G4Y6ZI4wPnZ_dQZ5ZQtyxHVTsFg12LDXG9_b6DOTcxzqAQVlj1dnCKsXXAHFA3o-RRdFTrTtGu2ps2uifqzVvafpnI_tEPgXcspmHiLgjAjw-badGxX2G8lPS5IbZH6L3c0T_uGi-j7-CoQPQHFxzW-idP6MIXmHvbBsUA6LmBhi8sl498DbWDoIerLGGee_FBLaZe5xCnRpiqzIs3tyBudJe4O3ay9hmA_wk_2-PRbb3J-1YCGUUXggurKsdv4xg93qPtBxtmWYtaKAl0uihVIafi9HlnuocefY2ORzIgIUJCnToC5rO1ckbFfxduYyBzAkRaYdbDoASxQuZH1ELpu728EA-BV873o1cp1bJya1lUR78GCE7z_dD-zuhr1t_bQIwO3Jd1fA_vF1mjUSLl6oONg_PHLbP--KlprZUluus1GmSapq-9czhtVkEATkEsIFQigOhLNRi1eLPAFXKDIjcRBsZ_bTzmkw3LvgKgh-Y6iux0RktToK1UpT1mM-8uEf4r8YnbTWK42VWbSYNMm92XKZ_2o11Q8uLi6hy1EW6AE5M5vl-g7icPt5YrtB9jRMiEV5lPGgvpHEF0hb1mTRHGKe5P9sRUoEm-YSmUlt5nUT0ihFyPKAzTf43NkrShiZUOv7NUPGmRIW_A2gwlIzekFxrCh-fxezuxv3cmjv7EziTDhkwDB7zDJahmt52J39yJYqGjHoPQ7s91heHJ_xIz9RbAnKDzVQVHY70JMJ7Z59P-TtIzSL9AZNFvmd8N1pdGrdascr9mozcKi1lrXifVN955Qa4lNrYe3gtjmMlHDDhlwNDMS_C1v6QvrNFeUA1x_eQDzgJ8sWFM-IC55UqjnkjSvgh1xE-WjrwFqoriMsI5mUhlsQ4GuK1EvxSc23gI5bmYRsU5bGwurFdVzNlW7VqbYJreqsPxFTWwJk8t-6dv9hpEBW6UkxQFgiMIobDifGjQX0hF3fA4fTD17p777MX8fEXXsJeLNDsJ_NE8AUoh561nL3lSW8pWrZJlqE3OMHsnORxCJuF9wGrsVSB0gB3Q7qv1849NM3O_KW4CfYocarQ1idxCqQfPg4tF8trQALaIBjtoNAFCPQ420pv1jCr9dw8_h_fj9cTlsG7m6H_-X_iOLv1u2aCno-W39lSWVbovjbaUWamW_SxplbrTb9Fh17rU_B2nCFPRQs5wohTnqFCSOyKA34m0qE9yASIicklgCmCUoOdoTgMo02sLmzW8bTQTQ5Xt8gqu1oie8SqaGEuV_vDQB-Apmi-yNuPzFA2gQ7B_2I7qPtPYbAUMg2y6-fZ995bkyE--D3ZbhSt17n6MI3Qr83cyEdjFSi9ZNyUBUi1KK7L5PS3oowL6QO8EMz6mZn4cS9UrE1HTUR-4P0MtMROHh2FnBu46M4p66Fn0tsRmFlEoizCTBxHJEKh2O0v8PL47nA8d6JTfbDhft2GzS96opKoht-wWwROzLxDaImRfBpnRMHk3OfRUXGEEMgK5_RHtED8U-_FZPjazEq160_iJw50_IhN8_gMqaIZd4fTy82ebr2L3rWoMTtX30RPj_k-aPd2VguJ4STtBUdCnm3L0qLdkpVWeq2qK046JFuqiMypN8W9r1ZbKrLIKrKDc3nIyJABeTfRyof4FEaE6tFuJPCMAGRdHxWuwviI9UxIQ0YFSn9KSzubX_kZrEqLYzfbefadbd9V3vMvRU9pBJ8aj4gBk2s4xK_VkXlXtvwFVujEqbigiWTRiUSSqzciW2TcS0lpMBamKbkPRAlIA2NXtYfximIloUKvxLf0hHRD1lMtDWw65Lrp37jphmv5XF2XxOKoVeKvrFJUyFTul1IrPt_7wANpRbgbVVl62tvKSAdnI8Mk1fa5hXYnwUgu_lAeBiS871Q0QAVCw9odgZ2kj6n7k_pQUxGOAkRPjhW_odeWPXh5c34balWiRdKIXFmo-KYo_5HaL4MO0Ad2IfiHwjGZvgIFf_hsk0FmBPgog5nFb0xznKWg8B7PNJpXNMuiNpjb5V6ruF2apWJrUa-3eX5qarC5txDm9nCgWlLLE-e--L0ab_6QW3w6dE4Y4FyyH6Azosdmz0GKQpanTY4NFMDbztT4Q9pc3gxPtx_aSDtfC088k5w2X8X5p4Jn_54D7O_oM26d2VqWaBpit1KxPZchBBM9oT-uMjWD2_8j821ueTkV8eQ4yd75-5P0DjsJHCR6M3tYXMKq8o3Dfu1TT5irDYprAbJQdXNpMrnLQbd6AyeU9l_X8ek-uZO3an9ION7PrhQySL5_Sn9Z7Ty4L2xP7wv-vTEtagTwAA',
            'style'     => 'H4sIAAAAAAAAAyXMSwqAIBAA0KsIbftuVVp6j0lHEmRGdCAjunuL3gGebXJn3GEOUE68Hs-Zqx6ccyYyiT44B7WtpSuoCfLYgNrUsKZoBLtMAT1XkMSkiQnNa5d__AAgw6_PWQAAAA',
            'vanity'    => 'H4sIAAAAAAAAA22S3U7DMAyFX8XKbtk6Bkxa1laIaQghwSZ-LrhMm6wNhDhyzMrenrSMG0CRJTuKv3OcJGdVOQO1cS4GVVvfFGIq-jIorY9lhaQN9VnkgzOFqFT91hB-eC1Hi8Vi2VnNrZydTcPnUpQ5UwoNe-Vs4wvBGH4aj1AJp-ETZikuUpynrm-JMdmmZRnRWT0cGa1Wq56YvHk4MnboWVboNPR6oMgqdxKVj-NoyO6WNTokOZrP58ukLHtPAaNli16ScYrt3iTmZZ711DLPWP-xC8fcmR0L-GX-LKlO0zr_nlZBS2ZXiJY5yCzrum4SCF9NzS16cwjIE6QmE1A7FWMhtAqt6UR5t767Wj_A5hq2D5vb9eoJbjb36xfYbp7yTJV5Rf-yP3yy_T6p8V38Aj6mfbhRtDeRDcGWkJOJNDbcG-6Q3npksra32mioDvA8oAax4RKy_uGy4UeUX2-deNUZAgAA',
        ]);
        $factory->setCallbackData([
            'emailCallback' => function($email, $style = null){
                $value = $email;
                $display = 'style="display:' . ['none',' none'][random_int(0,1)] . '"';
                $style = $style ?? random_int(0,5);
                $props[] = "href=\"mailto:$email\"";
        
                $wrap = function($value, $style) use($display){
                    switch($style){
                        case 2: return "<!-- $value -->";
                        case 4: return "<span $display>$value</span>";
                        case 5:
                            $id = 'br7resi';
                            return "<div id=\"$id\">$value</div>\n<script>document.getElementById('$id').innerHTML = '';</script>";
                        default: return $value;
                    }
                };
        
                switch($style){
                    case 0: $value = ''; break;
                    case 3: $value = $wrap($email, 2); break;
                    case 1: $props[] = $display; break;
                }
        
                $props = implode(' ', $props);
                $link = "<a $props>$value</a>";
        
                return $wrap($link, $style);
            }
        ]);

        $transcriber = new DataTranscriber($templateData, $factory);

        $template = new ArrayTemplate([
            'doctype',
            'injDocType',
            'head1',
            'injHead1HTMLMsg',
            'robots',
            'injRobotHTMLMsg',
            'nocollect',
            'injNoCollectHTMLMsg',
            'head2',
            'injHead2HTMLMsg',
            'top',
            'injTopHTMLMsg',
            'actMsg',
            'errMsg',
            'customMsg',
            'legal',
            'injLegalHTMLMsg',
            'altLegalMsg',
            'emailCallback',
            'injEmailHTMLMsg',
            'style',
            'injStyleHTMLMsg',
            'vanity',
            'injVanityHTMLMsg',
            'altVanityMsg',
            'bottom',
            'injBottomHTMLMsg',
        ]);

        $hp = new Script($client, $transcriber, $template, $templateData, $factory);
        $hp->handle($host, $port, $script);
    }

    public function handle($host, $port, $script)
    {
        $data = [
            'tag1' => '86f6004a7546ff0424b7564ae7d4fac7',
            'tag2' => '4ba48493d098c1dab280acc142e8f168',
            'tag3' => '3649d4e9bcfd3422fb4f9d22ae0a2a91',
            'tag4' => md5_file(__FILE__),
            'version' => "php-".phpversion(),
            'ip'      => $_SERVER['REMOTE_ADDR'],
            'svrn'    => $_SERVER['SERVER_NAME'],
            'svp'     => $_SERVER['SERVER_PORT'],
            'sn'      => $_SERVER['SCRIPT_NAME']     ?? '',
            'svip'    => $_SERVER['SERVER_ADDR']     ?? '',
            'rquri'   => $_SERVER['REQUEST_URI']     ?? '',
            'phpself' => $_SERVER['PHP_SELF']        ?? '',
            'ref'     => $_SERVER['HTTP_REFERER']    ?? '',
            'uagnt'   => $_SERVER['HTTP_USER_AGENT'] ?? '',
        ];

        $headers = [
            "User-Agent: PHPot {$data['tag2']}",
            "Content-Type: application/x-www-form-urlencoded",
            "Cache-Control: no-store, no-cache",
            "Accept: */*",
            "Pragma: no-cache",
        ];

        $subResponse = $this->client->request("POST", "http://$host:$port/$script", $headers, $data);
        $data = $this->transcriber->transcribe($subResponse->getLines());
        $response = new TextResponse($this->template->render($data));

        $this->serve($response);
    }

    public function serve(Response $response)
    {
        header("Cache-Control: no-store, no-cache");
        header("Pragma: no-cache");

        print $response->getBody();
    }
}

Script::run(__REQUEST_HOST, __REQUEST_PORT, __REQUEST_SCRIPT, __DIR__ . '/phpot_settings.php');

